# CodeAct (SWE Edit Specialized)

This agent is an adaptation of the original [SWE Agent](https://swe-agent.com/) based on CodeAct using the `agentskills` library of OpenHands.

Its intended use is **solving GitHub issues**.

It removes web-browsing and GitHub capability from the original CodeAct agent to avoid confusion to the agent.
